@@ -6,7 +6,10 @@ from django.contrib.auth.models import User
 from django.core.exceptions import ImproperlyConfigured, PermissionDenied
 from django.template import Template
 
-from snippetscream import RequestFactory
+try:
+    from django.test.client import RequestFactory
+except ImportError:
+    from snippetscream import RequestFactory
 
 from object_tools import autodiscover
 from object_tools.options import ObjectTool
@@ -68,11 +71,17 @@ class ObjectToolsInclusionTagsTestCase(TestCase):
     """
     Testcase for object_tools.templatetags.object_tools_inclusion_tags.
     """
+    def setUp(self):
+        self.factory = RequestFactory()
+        self.user = User.objects.create_user(username='test_user')
+
     def test_object_tools(self):
         autodiscover()
+        request = self.factory.get('/')
+        request.user = self.user
         context = template.Context({
             'model': User,
-            'request': RequestFactory().get('/'),
+            'request': request,
         })
         t = Template("{% load object_tools_inclusion_tags %}{% object_tools \
                 model request.user %}")
@@ -94,12 +103,15 @@ class ObjectToolsInclusionTagsTestCase(TestCase):
         user.is_superuser = True
         user.save()
         result = t.render(context)
-        expected_result = u'\n    <li><a href="/object-tools/auth/user/\
-test_tool/" title=""class="historylink">Test Tool</a></li>\n\n    \
-<li><a href="/object-tools/auth/user/test_media_tool/" title=""\
+        expected_result = u'\n<li><a href="/object-tools/auth/user/\
+test_tool/?" title=""class="historylink">Test Tool</a></li>\n\n\
+<li><a href="/object-tools/auth/user/test_media_tool/?" title=""\
 class="historylink"></a></li>\n\n'
         self.failUnlessEqual(result, expected_result)
 
+    def tearDown(self):
+        self.user.delete()
+
 
 class ObjectToolsTestCase(TestCase):
     """
@@ -129,39 +141,35 @@ class ObjectToolsTestCase(TestCase):
         # With a tool registered, urls should include it for each model.
         tools.register(TestTool)
         urls = tools.urls
-        self.failUnlessEqual(len(urls[0]), 8)
+        self.failUnlessEqual(len(urls[0]), 6)
+        print [url.url_patterns[0].__repr__() for url in urls[0]]
         for url in urls[0]:
-            self.failUnless(url.__repr__() in [
-            '<RegexURLResolver [<RegexURLPattern auth_message_test_tool \
-^test_tool/$>] (None:None) ^auth/message/>',
-            '<RegexURLResolver [<RegexURLPattern auth_group_test_tool \
-^test_tool/$>] (None:None) ^auth/group/>',
-            '<RegexURLResolver [<RegexURLPattern contenttypes_contenttype\
-_test_tool ^test_tool/$>] (None:None) ^contenttypes/contenttype/>',
-            '<RegexURLResolver [<RegexURLPattern sites_site_test_tool \
-^test_tool/$>] (None:None) ^sites/site/>',
-            '<RegexURLResolver [<RegexURLPattern auth_permission_test_tool \
-^test_tool/$>] (None:None) ^auth/permission/>',
-            '<RegexURLResolver [<RegexURLPattern auth_user_test_tool \
-^test_tool/$>] (None:None) ^auth/user/>',
-            '<RegexURLResolver [<RegexURLPattern sessions_session_test_tool \
-^test_tool/$>] (None:None) ^sessions/session/>',
-            '<RegexURLResolver [<RegexURLPattern admin_logentry_test_tool \
-^test_tool/$>] (None:None) ^admin/logentry/>'
-        ])
+            self.failUnless(url.url_patterns[0].__repr__() in [
+                '<RegexURLPattern sessions_session_test_tool ^test_tool/$>',
+                '<RegexURLPattern auth_user_test_tool ^test_tool/$>',
+                '<RegexURLPattern auth_group_test_tool ^test_tool/$>',
+                '<RegexURLPattern auth_permission_test_tool ^test_tool/$>',
+                '<RegexURLPattern contenttypes_contenttype_test_tool ^test_tool/$>',
+                '<RegexURLPattern admin_logentry_test_tool ^test_tool/$>'
+            ])
 
 
 class ObjectToolTestCase(TestCase):
     """
     Testcase for object_tools.options.ObjectTool.
     """
+    def setUp(self):
+        self.factory = RequestFactory()
+        self.user = User.objects.create_user(username='test_user')
+
     def test_init(self):
         tool = ObjectTool(User)
         self.failUnless(tool.model == User, 'Object Tool should have \
                 self.model set on init.')
 
     def test_construct_context(self):
-        request = RequestFactory().get('/')
+        request = self.factory.get('/')
+        request.user = self.user
         tool = TestTool(User)
         context = tool.construct_context(request)
 
@@ -179,15 +187,16 @@ class ObjectToolTestCase(TestCase):
         form = tool.construct_form(MockRequest())
         media = tool.media(form)
 
-        #Media result should include default admin media.
-        self.failUnlessEqual(media.render_js(), [u'<script type="\
-text/javascript" src="/static/admin/js/core.js"></script>', \
-u'<script type="text/javascript" src="/static/admin/js/admin/\
+        # Media result should include default admin media.
+        self.failUnlessEqual(media.render_js(), [
+            u'<script type="\
+text/javascript" src="/static/admin/js/core.js"></script>',
+            u'<script type="text/javascript" src="/static/admin/js/admin/\
 RelatedObjectLookups.js"></script>', u'<script type=\
 "text/javascript" src="/static/admin/js/jquery.min.js">\
 </script>', u'<script type="text/javascript" src=\
-"/static/admin/js/jquery.init.js"></script>'], \
-'Media result should include default admin media.')
+"/static/admin/js/jquery.init.js"></script>'
+        ], 'Media result should include default admin media.')
 
         tool = TestMediaTool(User)
         form = tool.construct_form(MockRequest())
@@ -233,18 +242,18 @@ to how admin does, except pointing to the particular tool.")
 
     def test_view(self):
         # Should raise permission denied on anonymous user.
-        request = RequestFactory().get('/')
+        request = self.factory.get('/')
+        request.user = self.user
         tool = TestTool(User)
         self.failUnlessRaises(PermissionDenied, tool._view, request)
 
         # Should raise permission denied for user without permissions.
-        user = User(username='test_view')
-        user.save()
-        request.user = user
         self.failUnlessRaises(PermissionDenied, tool._view, request)
 
         # Should not raise permission denied for super user.
-        user.is_superuser = True
-        user.save()
-        request.user = user
+        request.user.is_superuser = True
+        request.user.save()
         tool._view(request)
+
+    def tearDown(self):
+        self.user.delete()
